import colors from 'vuetify/es5/util/colors'



export default {
  // Global page headers: https://go.nuxtjs.dev/config-head
  head: {
    script: [
      { src: 'https://static.nid.naver.com/js/naveridlogin_js_sdk_2.0.0.js' },
      { src: 'https://docs.opencv.org/3.4/opencv.js' },
    ],
    titleTemplate: 'Vridge AI - %s',
    title: 'Vridge AI',
    htmlAttrs: {
      lang: 'ko'
    },
    meta: [
      { charset: 'utf-8' },
      { name: 'viewport', content: 'width=device-width, initial-scale=1' },
      { hid: 'og:title', property: 'og:title', content: 'Vridge AI' },
      { hid: 'og:site_name', property: 'og:site_name', content: 'Vridge AI' },
      { hid: 'description', name: 'description', content: '클라우드 환경에서 인공지능 모델을 학습하고 배포 및 버전 관리 서비스' },
      { hid: 'og:image', property: 'og:image', content: 'https://d2q9yzkd471o7j.cloudfront.net/logo/head_logo.png?w=300&h=300' }
    ],
    link: [
      { rel: 'icon', type: 'image/x-icon', href: '/favicon.ico' },
      { rel: 'preconnect', href: 'https://fonts.gstatic.com' },
      { rel: 'stylesheet', href: 'https://fonts.googleapis.com/css2?family=Noto+Sans+KR:wght@100;300;400;500;700;900&display=swap' },
      { rel: 'stylesheet', href: 'https://fonts.googleapis.com/earlyaccess/nanumgothic.css'},
      { rel: 'stylesheet', href: 'https://cdn.jsdelivr.net/npm/@mdi/font@6.5.95/css/materialdesignicons.min.css'},
    ]
  },

  loading:false,

  // Global CSS: https://go.nuxtjs.dev/config-css
  css: [
    "~/assets/scss/common.scss",
    "~/assets/scss/guide.scss",
  ],

  // Plugins to run before rendering page: https://go.nuxtjs.dev/config-plugins
  plugins: [
    //'~/plugins/global.js'
    {src:'~/plugins/vuex-persis.js', ssr:false},
  ],

  // Auto import components: https://go.nuxtjs.dev/config-components
  components: true,

  buildModules: [
    '@nuxtjs/axios',
    '@nuxtjs/vuetify',
    '@nuxtjs/svg'
  ],

  // Modules: https://go.nuxtjs.dev/config-modules
  modules: [
    'nuxt-healthcheck',
    '@nuxtjs/markdownit'
  ],

  // Vuetify module configuration: https://go.nuxtjs.dev/config-vuetify
  vuetify: {
    customVariables: ['~/assets/variables.scss'],
    heme: {
      dark: true,
      themes: {
        dark: {
          primary: colors.blue.darken2,
          accent: colors.grey.darken3,
          secondary: colors.amber.darken3,
          info: colors.teal.lighten1,
          warning: colors.amber.base,
          error: colors.deepOrange.accent4,
          success: colors.green.accent3
        }
      }
    },
    defaultAssets: {
      font: {
        family: 'Noto Sans KR'
      }
    }
  },

  animejs: true,

  // Build Configuration: https://go.nuxtjs.dev/config-build
  build: {
    vendor: ['axios'],
    hotMiddleware:{
      client:{
        quiet:true
      }
    },
    html: {
      minify: {
        collapseWhitespace: true,  // as @dario30186 mentioned
        removeComments: true, // 👈 add this line
      },
    },
    extend (config, ctx) {
      config.module.rules.push({
        enforce: 'pre',
        test: /\.txt$/,
        loader: 'raw-loader',
        exclude: /(node_modules)/
      });
    }
  },

  axios:{
    host: "http://docs.vridgeai.com",
    prefix: "/api",
  },
  
  healthCheck: {
    contentType: 'application/json',
    healthy: () => {
      return JSON.stringify({result: 'ok'})
    }
  },

  markdownit: {
    preset: 'default',
    linkify: true,
    breaks: true,
    use: [
      'markdown-it-div',
      'markdown-it-attrs'
    ]
  }
}